@@ -9,6 +9,7 @@
 
 namespace apps
 {
+class AMAppItem;
 class AMAppItemModel : public AppItemModel
 {
     Q_OBJECT
@@ -16,6 +17,8 @@ class AMAppItemModel : public AppItemModel
 public:
     explicit AMAppItemModel(QObject *parent = nullptr);
 
+    AMAppItem * appItem(const QString &id);
+
 private:
     ObjectManager *m_manager;
 };
