@@ -11,8 +11,8 @@
 
 DS_USE_NAMESPACE
 
-namespace apps
-{
+namespace apps {
+class AMAppItemModel;
 class AppItem;
 class AppsApplet : public DApplet
 {
@@ -30,7 +30,7 @@ public:
     QAbstractItemModel *groupModel() const;
 
 private:
+    AMAppItemModel *m_appModel;
     QAbstractItemModel *m_groupModel;
-    QAbstractItemModel *m_appModel;
 };
 }
