@@ -11,10 +11,42 @@
 #include <QtWaylandCompositor/QWaylandResource>
 #include <cstdint>
 
+#include "qwayland-server-fractional-scale-v1.h"
 #include "qwayland-server-plugin-manager-v1.h"
 
 class PluginSurface;
 class PluginPopup;
+class PluginScale;
+class PluginScaleManager : public QWaylandCompositorExtensionTemplate<PluginScaleManager>, public QtWaylandServer::wp_fractional_scale_manager_v1
+{
+    Q_OBJECT
+    QML_ELEMENT
+    Q_PROPERTY(uint32_t pluginScale READ pluginScale WRITE setPluginScale NOTIFY pluginScaleChanged)
+
+public:
+    PluginScaleManager(QWaylandCompositor *compositor = nullptr);
+    uint32_t pluginScale();
+    void setPluginScale(const uint32_t &scale);
+
+    void initialize() override;
+    void wp_fractional_scale_manager_v1_get_fractional_scale(Resource *resource, uint32_t id, struct ::wl_resource *surface) override;
+
+Q_SIGNALS:
+    void pluginScaleChanged(uint32_t scale);
+
+private:
+    uint32_t m_scale;
+    QWaylandCompositor *m_compositor;
+};
+
+class PluginScale : public QWaylandCompositorExtensionTemplate<PluginScale>, public QtWaylandServer::wp_fractional_scale_v1
+{
+    Q_OBJECT
+public:
+    PluginScale(PluginScaleManager *manager, QWaylandSurface *surface, const QWaylandResource &resource);
+    void wp_fractional_scale_v1_destroy(Resource *resource) override;
+};
+
 class PluginManager : public QWaylandCompositorExtensionTemplate<PluginManager>, public QtWaylandServer::plugin_manager_v1
 {
     Q_OBJECT
@@ -51,6 +83,12 @@ Q_SIGNALS:
     void pluginSurfaceDestroyed(PluginSurface*);
     void messageRequest(PluginSurface *, const QString &msg);
     void dockSizeChanged();
+    void requestShutdown(const QString &type);
+
+private Q_SLOTS:
+    void onFontChanged();
+    void onActiveColorChanged();
+    void onThemeChanged();
 
 protected:
     virtual void plugin_manager_v1_request_message(Resource *resource, const QString &plugin_id, const QString &item_key, const QString &msg) override;
@@ -64,12 +102,14 @@ private:
     void sendEventMsg(Resource *target, const QString &msg);
     QString dockSizeMsg() const;
     QString popupMinHeightMsg() const;
+    using PluginSurfaceCallback = std::function<void(Resource *)>;
+    void foreachPluginSurface(PluginSurfaceCallback callback);
 
 private:
     QList<PluginSurface*> m_pluginSurfaces;
 
-    uint32_t m_dockPosition;
-    uint32_t m_dockColorTheme;
+    uint32_t m_dockPosition = 0;
+    uint32_t m_dockColorTheme = 0;
     QSize m_dockSize;
     int m_popupMinHeight = 0;
 };
@@ -83,7 +123,8 @@ class PluginSurface : public QWaylandShellSurfaceTemplate<PluginSurface>, public
     Q_PROPERTY(uint32_t pluginType READ pluginType CONSTANT)
     Q_PROPERTY(uint32_t pluginSizePolicy READ pluginSizePolicy CONSTANT)
     Q_PROPERTY(QString displayName READ displayName CONSTANT)
-    Q_PROPERTY(QSize size READ pluginSize NOTIFY sizeChanged)
+    Q_PROPERTY(int height READ height NOTIFY heightChanged)
+    Q_PROPERTY(int width READ width NOTIFY widthChanged)
     Q_PROPERTY(bool isItemActive WRITE setItemActive READ isItemActive NOTIFY itemActiveChanged)
     Q_PROPERTY(QString dccIcon READ dccIcon CONSTANT)
     Q_PROPERTY(int margins READ margins WRITE setMargins NOTIFY marginsChanged FINAL)
@@ -109,9 +150,12 @@ public:
     uint32_t pluginType() const;
     uint32_t pluginFlags() const;
     uint32_t pluginSizePolicy() const;
-    QSize pluginSize() const;
+
     QString dccIcon() const;
 
+    int height() const;
+    int width() const;
+
     void setItemActive(bool isActive);
     bool isItemActive() const;
 
@@ -123,7 +167,8 @@ public:
 
 signals:
     void itemActiveChanged();
-    void sizeChanged();
+    void heightChanged();
+    void widthChanged();
     void recvMouseEvent(QEvent::Type type);
 
     void marginsChanged();
@@ -132,9 +177,11 @@ signals:
 protected:
     virtual void plugin_mouse_event(Resource *resource, int32_t type) override;
     virtual void plugin_dcc_icon(Resource *resource, const QString &icon) override;
+    virtual void plugin_request_shutdown(Resource *resource, const QString &type) override;
     virtual void plugin_close_quick_panel(Resource *resource) override;
     virtual void plugin_destroy_resource(Resource *resource) override;
     virtual void plugin_destroy(Resource *resource) override;
+    virtual void plugin_source_size(Resource *resource, int32_t width, int32_t height) override;
 
 private:
     PluginManager* m_manager;
@@ -151,6 +198,8 @@ private:
 
     bool m_isItemActive = false;
     int m_margins = 0;
+    int m_height;
+    int m_width;
 };
 
 class PluginPopup : public QWaylandShellSurfaceTemplate<PluginPopup>, public QtWaylandServer::plugin_popup
@@ -161,6 +210,8 @@ class PluginPopup : public QWaylandShellSurfaceTemplate<PluginPopup>, public QtW
     Q_PROPERTY(QString pluginId READ pluginId)
     Q_PROPERTY(QString itemKey READ itemKey)
     Q_PROPERTY(int32_t popupType READ popupType)
+    Q_PROPERTY(int height READ height NOTIFY heightChanged)
+    Q_PROPERTY(int width READ width NOTIFY widthChanged)
 
 public:
     PluginPopup(PluginManager* shell, const QString &pluginId, const QString &itemKey, int x, int y, int popupType,
@@ -184,6 +235,9 @@ public:
 
     int32_t popupType() const;
 
+    int height() const;
+    int width() const;
+
 signals:
     void aboutToDestroy();
 
@@ -191,10 +245,13 @@ protected:
     virtual void plugin_popup_set_position(Resource *resource, int32_t x, int32_t y) override;
     virtual void plugin_popup_destroy_resource(Resource *resource) override;
     virtual void plugin_popup_destroy(Resource *resource) override;
+    virtual void plugin_popup_source_size(Resource *resource, int32_t width, int32_t height) override;
 
 Q_SIGNALS:
     void xChanged();
     void yChanged();
+    void heightChanged();
+    void widthChanged();
 
 private:
     PluginManager* m_manager;
@@ -206,6 +263,9 @@ private:
 
     int32_t m_x;
     int32_t m_y;
+    int m_height;
+    int m_width;
 };
 
 Q_COMPOSITOR_DECLARE_QUICK_EXTENSION_CLASS(PluginManager)
+Q_COMPOSITOR_DECLARE_QUICK_EXTENSION_CLASS(PluginScaleManager)
