@@ -8,8 +8,8 @@
 
 #include <cstdint>
 
-#include <QAbstractListModel>
 #include <QObject>
+#include <QAbstractListModel>
 
 namespace dock {
 class AppItem;
@@ -22,10 +22,10 @@ public:
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &index, int role = AbstractWindow::winIdRole) const override;
 
-    void trackWindow(AbstractWindow *window);
-    void destroyWindow(AbstractWindow *window);
+    void trackWindow(AbstractWindow* window);
+    void destroyWindow(AbstractWindow * window);
 
-    AbstractWindowMonitor(QObject *parent = nullptr);
+    AbstractWindowMonitor(QObject* parent = nullptr);
     virtual void start() = 0;
     virtual void stop() = 0;
     virtual void clear() = 0;
@@ -40,9 +40,11 @@ public:
 
 Q_SIGNALS:
     void windowAdded(QPointer<AbstractWindow> window);
+    // true -> At least one window is at fullscreen state. false -> none of the windows is at fullscreen state.
+    void windowFullscreenChanged(bool);
     void WindowMonitorShutdown();
 
 private:
-    QList<AbstractWindow *> m_trackedWindows;
+    QList<AbstractWindow*> m_trackedWindows;
 };
 }
