@@ -15,11 +15,11 @@
     </message>
     <message>
         <source>Classic Mode</source>
-        <translation>Modo clássico</translation>
+        <translation>Clássico</translation>
     </message>
     <message>
         <source>Centered Mode</source>
-        <translation>Modo centralizado</translation>
+        <translation>Centralizado</translation>
     </message>
     <message>
         <source>Left</source>
@@ -65,5 +65,9 @@
         <source>Dock Settings</source>
         <translation>Configurações do dock</translation>
     </message>
+    <message>
+        <source>Lock the Dock</source>
+        <translation>Desativar ajuste</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
