@@ -180,15 +180,9 @@ uint NotificationManager::Notify(const QString &appName, uint replacesId, const
                                  const QString &body, const QStringList &actions, const QVariantMap &hints,
                                  int expireTimeout)
 {
-    qDebug(notifyLog) << "Notify"
-            << ", appName:" << appName
-            << ", summary:" << summary
-            << ", appIcon:" << appIcon
-            << ", body size:" << body.size()
-            << ", actions:" << actions
-            << ", hint: " << hints
-            << ", replaceId:" << replacesId
-            << ", expireTimeout:" << expireTimeout;
+    qInfo(notifyLog) << "Notify"
+                     << ", appName:" << appName << ", summary:" << summary << ", appIcon:" << appIcon << ", body size:" << body.size()
+                     << ", actions:" << actions << ", hint: " << hints << ", replaceId:" << replacesId << ", expireTimeout:" << expireTimeout;
 
     if (calledFromDBus() && m_setting->systemValue(NotificationSetting::CloseNotification).toBool()) {
         qDebug(notifyLog) << "Notify has been disabled by CloseNotification setting.";
@@ -649,6 +643,13 @@ void NotificationManager::onHandingPendingEntities()
     }
 
     for (const auto &item : timeoutEntities) {
+        // Validate entity before processing timeout to prevent race conditions
+        if (!item.isValid()) {
+            qWarning(notifyLog) << "Skipping timeout processing for invalid entity id:" << item.id() << "appName:" << item.appName()
+                                << "cTime:" << item.cTime();
+            continue;
+        }
+
         qDebug(notifyLog) << "Expired for the notification " << item.id() << item.appName();
         notificationClosed(item.id(), item.bubbleId(), NotifyEntity::Expired);
     }
